==> terasoluna-server4jweb-all_2.0.1.0.zip: functionsample-thin/sources/jp/terasoluna/thin/functionsample/database/bean/AddressTableVO.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.thin.functionsample.database.bean;

/**
 * f[^x[Xe[uVO
 *
 */
public class AddressTableVO {
    /**
     * ڋqR[h
     */
    private String customerCode = null;
    
    /**
     * ڋq
     */
    private String customerName = null;
    
    /**
     * X֔ԍ
     */
    private String postCode = null;
    
    /**
     * Z
     */
    private String customerAddress = null;
    
    /**
     * dbԍ
     */
    private String customerTel = null;
    
    /**
     * Z擾B
     * @return customerAddress
     */
    public String getCustomerAddress() {
        return customerAddress;
    }
    
    /**
     * Zݒ肷B
     * @param customerAddress 及
     */
    public void setCustomerAddress(String customerAddress) {
        this.customerAddress = customerAddress;
    }
    
    /**
     * ڋqR[h擾B
     * @return customerCode
     */
    public String getCustomerCode() {
        return customerCode;
    }
    
    /**
     * ڋqR[hݒ肷B
     * @param customerCode ڋqR[h
     */
    public void setCustomerCode(String customerCode) {
        this.customerCode = customerCode;
    }
    
    /**
     * ڋq擾B
     * @return customerName
     */
    public String getCustomerName() {
        return customerName;
    }
    
    /**
     * ڋqݒ肷B
     * @param customerName ڋq
     */
    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    
    /**
     * dbԍ擾B
     * @return customerTel
     */
    public String getCustomerTel() {
        return customerTel;
    }
    
    /**
     * dbԍݒ肷B
     * @param customerTel dbԍ
     */
    public void setCustomerTel(String customerTel) {
        this.customerTel = customerTel;
    }
    
    /**
     * X֔ԍ擾B
     * @return postCode
     */
    public String getPostCode() {
        return postCode;
    }
    
    /**
     * X֔ԍݒ肷B
     * @param postCode X֔ԍ
     */
    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }
}

==> terasoluna-server4jweb-all_2.0.5.3.zip: functionsample-thin/sources/jp/terasoluna/thin/functionsample/database/bean/AddressTableVO.java <==
/*
 * Copyright (c) 2007 NTT DATA Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.terasoluna.thin.functionsample.database.bean;

/**
 * f[^x[Xe[uVO
 *
 */
public class AddressTableVO {
    /**
     * ڋqR[h
     */
    private String customerCode = null;
    
    /**
     * ڋq
     */
    private String customerName = null;
    
    /**
     * X֔ԍ
     */
    private String postCode = null;
    
    /**
     * Z
     */
    private String customerAddress = null;
    
    /**
     * dbԍ
     */
    private String customerTel = null;
    
    /**
     * Z擾B
     * @return customerAddress
     */
    public String getCustomerAddress() {
        return customerAddress;
    }
    
    /**
     * Zݒ肷B
     * @param customerAddress 及
     */
    public void setCustomerAddress(String customerAddress) {
        this.customerAddress = customerAddress;
    }
    
    /**
     * ڋqR[h擾B
     * @return customerCode
     */
    public String getCustomerCode() {
        return customerCode;
    }
    
    /**
     * ڋqR[hݒ肷B
     * @param customerCode ڋqR[h
     */
    public void setCustomerCode(String customerCode) {
        this.customerCode = customerCode;
    }
    
    /**
     * ڋq擾B
     * @return customerName
     */
    public String getCustomerName() {
        return customerName;
    }
    
    /**
     * ڋqݒ肷B
     * @param customerName ڋq
     */
    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    
    /**
     * dbԍ擾B
     * @return customerTel
     */
    public String getCustomerTel() {
        return customerTel;
    }
    
    /**
     * dbԍݒ肷B
     * @param customerTel dbԍ
     */
    public void setCustomerTel(String customerTel) {
        this.customerTel = customerTel;
    }
    
    /**
     * X֔ԍ擾B
     * @return postCode
     */
    public String getPostCode() {
        return postCode;
    }
    
    /**
     * X֔ԍݒ肷B
     * @param postCode X֔ԍ
     */
    public void setPostCode(String postCode) {
        this.postCode = postCode;
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("AddressTableVO [");
        if (customerCode != null) {
            builder.append("customerCode=");
            builder.append(customerCode);
            builder.append(", ");
        }
        if (customerName != null) {
            builder.append("customerName=");
            builder.append(customerName);
            builder.append(", ");
        }
        if (postCode != null) {
            builder.append("postCode=");
            builder.append(postCode);
            builder.append(", ");
        }
        if (customerAddress != null) {
            builder.append("customerAddress=");
            builder.append(customerAddress);
            builder.append(", ");
        }
        if (customerTel != null) {
            builder.append("customerTel=");
            builder.append(customerTel);
        }
        builder.append("]");
        return builder.toString();
    }
}
